.. _recipe_asr.magstate:

asr.magstate
============


.. contents:: Contents
   :local:

Summary
-------

This is the documentation for :py:mod:`asr.magstate`-recipe.
This recipe is comprised of a single step, namely:

  - :py:func:`asr.magstate.main`

Run this recipe through the CLI interface

.. code-block:: console

   $ asr run asr.magstate

or as a python module

.. code-block:: console

   $ python -m asr.magstate

Detailed description
--------------------
Module for determining magnetic state.

Steps
-----


asr.magstate
^^^^^^^^^^^^
.. autofunction:: asr.magstate.main
   